<?php

namespace Litecms\Institute\Providers;

use Illuminate\Support\ServiceProvider;

class InstituteServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'institute');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'institute');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.institute', function ($app) {
            return $this->app->make('Litecms\Institute\Institute');
        });

        // Bind Institute to repository
        $this->app->bind(
            'Litecms\Institute\Interfaces\InstituteRepositoryInterface',
            \Litecms\Institute\Repositories\Eloquent\InstituteRepository::class
        );        // Bind Course to repository
        $this->app->bind(
            'Litecms\Institute\Interfaces\CourseRepositoryInterface',
            \Litecms\Institute\Repositories\Eloquent\CourseRepository::class
        );        // Bind InstituteCourse to repository
        $this->app->bind(
            'Litecms\Institute\Interfaces\InstituteCourseRepositoryInterface',
            \Litecms\Institute\Repositories\Eloquent\InstituteCourseRepository::class
        );

        $this->app->register(\Litecms\Institute\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Institute\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.institute'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/institute.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/institute')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/institute')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
